@@ -42,7 +42,7 @@ functions, seeing and atmospheric conditions.
 """
 
 
-__version__ = "2.5.1"
+__version__ = "2.6.0"
 
 __all__ = [
     "MIN_MATCHES_FRACTION",
@@ -561,7 +561,7 @@ def register(
 
 def _find_sources(img, detection_sigma=5, min_area=5, mask=None):
     """Return sources (x, y) sorted by brightness."""
-    import sep
+    import sep_pjw as sep
 
     image = img.astype("float32")
     bkg = sep.Background(image, mask=mask)
